# -*- coding: utf-8 -*-

"""
This file is part of datamatrix.

datamatrix is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public licensese as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

datamatrix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with datamatrix.  If not, see <http://www.gnu.org/licenses/>.
"""
from datamatrix.py3compat import *
import datamatrix.monkeypatch
from datamatrix._config import cfg
from datamatrix._datamatrix._row import Row
from datamatrix._datamatrix._mixedcolumn import MixedColumn
from datamatrix._datamatrix._numericcolumn import FloatColumn, IntColumn
from datamatrix._datamatrix._seriescolumn import SeriesColumn
from datamatrix._datamatrix._multidimensionalcolumn import \
    MultiDimensionalColumn
from datamatrix._datamatrix._nifticolumn import NiftiColumn
from datamatrix._datamatrix._datamatrix import DataMatrix

__version__ = '1.0.0'
NAN = float('nan')
INF = float('inf')
